@@ -26,9 +26,9 @@ def get_settings_module_name():
     """
     Returns the module's name to be used as the settings module
     for this project. It can be changed by the environment variable
-    `PYDISSANTO_SETTINGS_MODULE`.
+    `PYROCYMULUS_SETTINGS_MODULE`.
 
-    Defaults to 'pyrocumulus.settings'.
+    Defaults to 'settings'.
     """
     settings_module = os.environ.get('PYROCUMULUS_SETTINGS_MODULE') or \
         'settings'
@@ -50,3 +50,14 @@ def get_settings_module(module_name=None):
         raise ImportError(err_msg)
 
     return module
+
+
+class Settings():
+
+    def __getattr__(self, attrname):
+        return getattr(get_settings_module(), attrname)
+
+    def __setattr__(self, attrname, value):
+        raise AttributeError('you can\'t set here')
+
+settings = Settings()
